EMVA1288
========

The EMVA1288 module is a Python package to process and print results of an
EMVA1288 tests.

This is the reference implementation for the EMVA1288 Standard for
Measurement and Presentation of Specifications for Machine Vision
Sensors and Cameras.

+------------------+------------------+
| Software version | Standard version |
+==================+==================+
| Master           | 4.0              |
+------------------+------------------+
| 1.*.*            | 4.0              |
+------------------+------------------+
| 0.6.*            | 3.1              |
+------------------+------------------+
| 0.5.*            | 3.1              |
+------------------+------------------+

Please visit `Emva1288
Website <http://www.emva.org/standards-technology/emva-1288/>`__ for information
and latest releases of the standard.

.. end_of_package_description

Documentation
-------------
For more information visit `the documentation page
<http://emva1288.readthedocs.io/en/latest/>`__.
